SocketConnect class

Properties

dataset ↔ Map<String, dynamic>
getter/setter pair
done → Future
no setter
hashCode → int
The hash code for this object.
no setterinherited
request ↔ HttpRequest
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
websocket → WebSocket?
no setter

Methods

close() → void
Closes the current connection.
isUpgradeRequest() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited